Set up a Python environment for deep learning backends
Source:R/segment_cellpose.R
sg_setup_python.RdCreates and configures a Python virtual environment or conda environment with the requested deep learning segmentation backends (Cellpose, StarDist) installed.
Arguments
- envname
Character string naming the Python environment. Default is
"segmantr".- method
Character string specifying the environment type. One of
"auto"(default),"conda", or"virtualenv".- backends
Character vector of backends to install. Supported values are
"cellpose"and"stardist".- gpu
Logical; if
TRUE(default), attempts to install GPU-enabled versions of the backends.